pub struct ResolvedBindings { /* private fields */ }Expand description
Typed bindings visible to an activated extension.
Implementations
Sourceimpl ResolvedBindings
impl ResolvedBindings
Sourcepub fn get(
&self,
extension: &ExtensionMetadata,
reference: &BindingReference,
) -> Result<&BindingValue, FrameworkError>
pub fn get( &self, extension: &ExtensionMetadata, reference: &BindingReference, ) -> Result<&BindingValue, FrameworkError>
Looks up a binding owned by this extension or one of its direct dependencies.
Limiting access to direct dependencies makes an extension’s required contracts explicit instead of allowing it to rely on unrelated active extensions.
Sourcepub fn entity_type(
&self,
extension: &ExtensionMetadata,
reference: &BindingReference,
) -> Result<&EntityTypeId, FrameworkError>
pub fn entity_type( &self, extension: &ExtensionMetadata, reference: &BindingReference, ) -> Result<&EntityTypeId, FrameworkError>
Retrieves an entity-type binding and verifies its declared kind.
Sourcepub fn property(
&self,
extension: &ExtensionMetadata,
reference: &BindingReference,
) -> Result<&PropertyId, FrameworkError>
pub fn property( &self, extension: &ExtensionMetadata, reference: &BindingReference, ) -> Result<&PropertyId, FrameworkError>
Retrieves a property binding and verifies its declared kind.