Structs
- Binding
Declaration - A semantic binding declared by an extension.
- Binding
Key - A lowercase snake_case semantic-binding key.
- Binding
Reference - A fully qualified semantic binding reference, such as
wikidata:item_id_property. - Contract
Version - An exact integer version of an extension contract.
- Entity
Type Requirement - A partial requirement for an entity-type binding.
- Extension
Dependency - A dependency that must be available at one exact contract version.
- Extension
Id - A unique lowercase kebab-case extension identifier.
- Extension
Metadata - Static metadata that defines one extension contract.
- Ontology
Requirements - Partial ontology requirements that an extension declares for its bindings.
- Property
Requirement - A partial requirement for a property binding.
Nonescalar fields are unconstrained.
Enums
- Binding
Kind - The ontology identifier kind expected by a semantic binding.
Traits
- Knowledge
Base Extension - A concrete extension implementation without CLI coupling.