pub struct BindingReference { /* private fields */ }Expand description
A fully qualified semantic binding reference, such as wikidata:item_id_property.
Implementations
Sourceimpl BindingReference
impl BindingReference
pub fn new(extension_id: ExtensionId, key: BindingKey) -> Self
pub fn extension_id(&self) -> &ExtensionId
pub fn key(&self) -> &BindingKey
Sourcepub const fn from_static(extension_id: &'static str, key: &'static str) -> Self
pub const fn from_static(extension_id: &'static str, key: &'static str) -> Self
Constructs a canonical binding reference from static literals.
Invalid literals cause compilation to fail when used in a constant.