Module manifest

Module manifest 

Versioned, repository-local configuration for compiled extensions.

Structs

ExtensionManifest
The versioned extension configuration stored in a repository’s extensions.yaml.
ManifestActivation
The dependency-ordered extensions and typed bindings enabled for one repository.
ManifestExtension
The contract and semantic bindings activated for one extension.

Enums

ManifestDiagnostic
One stable semantic error found while validating a syntactically valid manifest.
ManifestError
Errors loading, activating, or resolving a repository extension manifest.

Constants

MANIFEST_FILE_NAME
MANIFEST_VERSION